@@ -23,9 +23,11 @@ import unicodedata
 from packaging import version
 import webbrowser
 import os
-import sys
 from pathlib import Path
 
+import sys
+# sys.stdin.reconfigure(encoding='utf-8')
+
 # %% Main
 def d3graph(adjmat, df=None, node_name=None, node_color='#000080', node_color_edge='#000000', node_size=10, node_size_edge=1, width=1500, height=800, collision=0.5, charge=250, edge_width=None, edge_distance=None, directed=False, edge_distance_minmax=[None,None], title='d3graph', slider=None, savepath=None, savename='index', cmap='Paired', showfig=True, verbose=3):
     """Make the interactive network in d3js.
@@ -443,11 +445,9 @@ def adjmat2G(adjmat, df, edge_distance_min=None, edge_distance_max=None, edge_wi
     for i in range(0, len(uilabels)):
         I1 = tmplabels['source']==uilabels[i]
         I2 = tmplabels['target']==uilabels[i]
-        adjmat['source'].loc[I1] = str(i)
-        adjmat['target'].loc[I2] = str(i)
+        adjmat.loc[I1, 'source'] = str(i)
+        adjmat.loc[I2, 'target'] = str(i)
 
-    # adjmat['source']=ismember(tmplabels['source'],uilabels)[1].astype(str)
-    # adjmat['target']=ismember(tmplabels['target'],uilabels)[1].astype(str)
     G = nx.Graph()
     # G.add_nodes_from(np.unique(uilabels))
     try:
